Utilities
=========

.. automodule:: psyneulink.core.globals.utilities
   :members: set_global_seed,is_numeric,is_numeric_or_none,is_iterable,norm,sinusoid,scalar_distance,powerset,tensor_power,convert_to_list,flatten_list,nesting_depth,get_args,recursive_update,np_array_less_that_2d,convert_to_np_array,get_value_from_array,is_matrix,underscore_to_camelCase,ReadOnlyOrderedDict,ContentAddressableList,

   :private-members:
   :exclude-members: parameter_spec,optional_parameter_spec,all_within_range,is_matrix, is_matrix_spec,iscompatible,is_value_spec, is_unit_interval, is_same_function_spec, is_component,is_comparison_operator,Modulation,get_modulationOperation_name, observe_value_at_keypath,insert_list,get_args,multi_getattr,type_match,append_type_to_name,make_readonly_property,get_class_attributes,get_global_seed,